import React, { Component } from 'react';
import { Field, reduxForm } from 'redux-form';
import PropTypes from 'prop-types';

class Form extends Component {
  static propTypes = {
    handleSubmit: PropTypes.func.isRequired,
    error: PropTypes.string
  };

  renderField = data => {
    data.input.className = 'form-control';

    const isInvalid = data.meta.touched && !!data.meta.error;
    if (isInvalid) {
      data.input.className += ' is-invalid';
      data.input['aria-invalid'] = true;
    }

    if (this.props.error && data.meta.touched && !data.meta.error) {
      data.input.className += ' is-valid';
    }

    return (
      <div className={`form-group`}>
        <label
          htmlFor={`donnee_${data.input.name}`}
          className="form-control-label"
        >
          {data.input.name}
        </label>
        <input
          {...data.input}
          type={data.type}
          step={data.step}
          required={data.required}
          placeholder={data.placeholder}
          id={`donnee_${data.input.name}`}
        />
        {isInvalid && <div className="invalid-feedback">{data.meta.error}</div>}
      </div>
    );
  };

  render() {
    return (
      <form onSubmit={this.props.handleSubmit}>
        <Field
          component={this.renderField}
          name="dateMutation"
          type="dateTime"
          placeholder="Date de la mutation."
        />
        <Field
          component={this.renderField}
          name="typeMutation"
          type="text"
          placeholder="Type de la mutation."
        />
        <Field
          component={this.renderField}
          name="valeurFonciere"
          type="number"
          step="0.1"
          placeholder="Valeur fonciere."
          normalize={v => parseFloat(v)}
        />
        <Field
          component={this.renderField}
          name="codeDpt"
          type="text"
          placeholder="Code du departement."
        />
        <Field
          component={this.renderField}
          name="typeLocal"
          type="text"
          placeholder="Type local."
        />
        <Field
          component={this.renderField}
          name="surface"
          type="text"
          placeholder="Surface reele batie."
        />

        <button type="submit" className="btn btn-success">
          Submit
        </button>
      </form>
    );
  }
}

export default reduxForm({
  form: 'donnee',
  enableReinitialize: true,
  keepDirtyOnReinitialize: true
})(Form);
